@@ -52,8 +52,10 @@ def _tag_class(dk: 'Digikam') -> type:                      # noqa: F821, C901
                 ``id == 0`` and ``pid == -1``, and there is no tag with
                 ``id == -1``. All other tags are descendents of
                 ``_Digikam_Root_Tag_``.
+            *   On MySQL, the ``Tags`` table implements an additional
+                *nested sets* structure with columns ``lft`` and ``rgt``.
 
-        See also:
+        .. seealso::
             * Class :class:`~digikamdb.tags.Tags`
         """
         
@@ -295,7 +297,7 @@ def _tag_class(dk: 'Digikam') -> type:                      # noqa: F821, C901
             if d <= 0 or d % 2 == 0:                        # pragma: no cover
                 raise DigikamDataIntegrityError(
                     'Tag table: inconsistent lft, rgt in id=%d (%d,%d)' % (
-                        self.id, self.lft, self.rgt
+                        self.id, self._lft, self._rgt
                     )
                 )
             pos = self._lft
@@ -428,12 +430,12 @@ class Tags(DigikamTable):
                     tags.c.id == instance.pid))
 
         connection.execute(
-            tags.update(tags.c.rgt >= new_position).values(
+            tags.update().where(tags.c.rgt >= new_position).values(
                 lft = case(
-                    [(
+                    (
                         tags.c.lft >= new_position,
                         tags.c.lft + 2,
-                    )],
+                    ),
                     else_ = tags.c.lft
                 ),
                 rgt = tags.c.rgt + 2,
@@ -485,12 +487,12 @@ class Tags(DigikamTable):
         right = instance._rgt
         
         connection.execute(
-            tags.update(tags.c.rgt > right).values(
+            tags.update().where(tags.c.rgt > right).values(
                 lft = case(
-                    [(
+                    (
                         tags.c.lft > right,
                         tags.c.lft - 2,
-                    )],
+                    ),
                     else_ = tags.c.lft
                 ),
                 rgt = tags.c.rgt - 2
